@@ -10,8 +10,8 @@ Copyright (c) 2001-2002, Prabhu Ramachandran.
 """
 
 __author__ = "Prabhu Ramachandran <prabhu_r@users.sf.net>"
-__version__ = "$Revision: 1.11 $"
-__date__ = "$Date: 2003/11/06 07:15:42 $"
+__version__ = "$Revision: 1.13 $"
+__date__ = "$Date: 2004/07/06 23:06:31 $"
 
 import Misc.LutHandler, Common, Tkinter
 
@@ -338,7 +338,11 @@ class ModuleManager:
         for f_name in self.fil_name:
             self._write_msg (file, "### %s ###\n"%f_name)
             fil = self.filter[f_name]
-            file.write ("%s\n"%fil.__class__.__name__)
+            if fil.__module__.find('Filters.') > -1:
+                # standard filter.
+                file.write ("%s\n"%fil.__class__.__name__)
+            else:
+                file.write ("User.%s\n"%fil.__class__.__name__)
             fil.save_config (file)
             self._write_msg (file, "### End of %s ###\n"%f_name)
         self._write_msg (file, "### End of Filters ###\n")
@@ -348,7 +352,10 @@ class ModuleManager:
         for m_name in self.mod_name:
             self._write_msg (file, "### %s ###\n"%m_name)
             mod = self.module[m_name]
-            file.write ("%s\n"%mod.__class__.__name__)
+            if mod.__module__.find('Modules.') > -1:
+                file.write ("%s\n"%mod.__class__.__name__)
+            else:
+                file.write ("User.%s\n"%mod.__class__.__name__)
             mod.save_config (file)
             self._write_msg (file, "### End of %s ###\n"%m_name)
         self._write_msg (file, "### End of Modules ###\n")
@@ -375,8 +382,13 @@ class ModuleManager:
             arg = None
             if name == "UserDefined":
                 arg = file.readline()[:-1]
-            fil_scr = __import__ ("%sFilters.%s"%(_PARENT, name),
-                                  globals (), locals (), [name])
+            if name[:5] == 'User.':
+                name = name[5:]
+                fil_scr = Common.mod_fil_import('Filters', name,
+                                                globals(), locals(), 1)
+            else:
+                fil_scr = __import__ ("%sFilters.%s"%(_PARENT, name),
+                                      globals(), locals(), [name])
             if arg:
                 fil = eval ("fil_scr.%s (self, arg)"%name)
             else:
@@ -394,8 +406,13 @@ class ModuleManager:
             arg = None
             if name == "Labels":
                 arg = -1
-            mod_scr = __import__ ("%sModules.%s"%(_PARENT, name),
-                                  globals (), locals (), [name])
+            if name[:5] == 'User.':
+                name = name[5:]
+                mod_scr = Common.mod_fil_import('Modules', name,
+                                                globals(), locals(), 1)
+            else:
+                mod_scr = __import__ ("%sModules.%s"%(_PARENT, name),
+                                      globals(), locals(), [name])
             if arg:
                 mod = eval ("mod_scr.%s (self, arg)"%name)
             else:
@@ -414,13 +431,13 @@ class ModuleManager:
         label = Tkinter.Label (frame, text="Filters")
         label.grid (row=0, column=0, sticky='ew', columnspan=2)
         scr = Tkinter.Scrollbar (frame, orient='vertical')
-	self.fil_lst = Tkinter.Listbox (frame, yscrollcommand=scr.set, 
+        self.fil_lst = Tkinter.Listbox (frame, yscrollcommand=scr.set, 
                                         selectmode='single', height=3,
                                         exportselection=0)
-	scr.config (command=self.fil_lst.yview)
+        scr.config (command=self.fil_lst.yview)
         self.fil_lst.grid (row=1, column=0, sticky='ewns')
         scr.grid (row=1, column=1, sticky='ns')
-	self.fil_lst.bind ("<Double-Button-1>", self.config_filter)
+        self.fil_lst.bind ("<Double-Button-1>", self.config_filter)
         
         but_f = Tkinter.Frame (master)
         but_f.pack (side='top', fill='both', expand=1)
@@ -448,13 +465,13 @@ class ModuleManager:
         label = Tkinter.Label (frame, text="Modules")
         label.grid (row=0, column=0, sticky='ew', columnspan=2)
         scr = Tkinter.Scrollbar (frame, orient='vertical')
-	self.mod_lst = Tkinter.Listbox (frame, yscrollcommand=scr.set, 
+        self.mod_lst = Tkinter.Listbox (frame, yscrollcommand=scr.set, 
                                         selectmode='single', height=4,
                                         exportselection=0)
-	scr.config (command=self.mod_lst.yview)
+        scr.config (command=self.mod_lst.yview)
         self.mod_lst.grid (row=1, column=0, sticky='ewns')
         scr.grid (row=1, column=1, sticky='ns')
-	self.mod_lst.bind ("<Double-Button-1>", self.config_module)
+        self.mod_lst.bind ("<Double-Button-1>", self.config_module)
 
         but_f = Tkinter.Frame (master)
         but_f.pack (side='top', fill='both', expand=1)
