@@ -11,17 +11,20 @@ Copyright (c) 2001-2003, Prabhu Ramachandran.
 """
 
 __author__ = "Prabhu Ramachandran <prabhu_r@users.sf.net>"
-__version__ = "$Revision: 1.13 $"
-__date__ = "$Date: 2004/07/14 21:10:24 $"
+__version__ = "$Revision: 1.17 $"
+__date__ = "$Date: 2005/08/02 18:26:23 $"
 __credits__ = """Many thanks to Jose Paulo <moitinho@civil.ist.utl.pt> 
 for adding tensor data support."""
 
 
-import Tkinter, vtkpython, math, tkColorChooser
+import Tkinter, tkColorChooser
+import vtk
+import math
 import Common, vtkPipeline.vtkPipeline 
 import vtkPipeline.vtkMethodParser
 import re
 import glob
+import os.path
 
 debug = Common.debug
 
@@ -226,16 +229,39 @@ def get_file_list (file_name):
     per this index."""
     
     debug ("In get_timestep_list ()")
-    
-    head = re.sub("[0-9]+[^0-9]*$", "", file_name)
-    tail = re.sub("^.*[0-9]+", "", file_name)
-    pattern = head+"[0-9]*"+tail
-    
-    files = glob.glob (pattern)
 
+    # The matching is done only for the basename of the file.
+    f_dir, f_base = os.path.split (file_name)
+    # Find the head and tail of the file pattern.
+    head = re.sub("[0-9]+[^0-9]*$", "", f_base)
+    tail = re.sub("^.*[0-9]+", "", f_base)
+    pattern = head+"[0-9]*"+tail
+    # Glob the files for the pattern.
+    _files = glob.glob (os.path.join(f_dir, pattern))
+
+    # A simple function to get the index from the file.
+    def _get_index(f, head=head, tail=tail):
+        base = os.path.split(f)[1]
+        result = base.replace(head, '')
+        return float(result.replace(tail, ''))
+
+    # Before sorting make sure the files in the globbed series are
+    # really part of a timeseries.  This can happen in cases like so:
+    # 5_2_1.vtk and 5_2_1s.vtk will be globbed but 5_2_1s.vtk is
+    # obviously not a valid time series file.
+    files = []
+    for x in _files:
+        try:
+            _get_index(x)
+        except ValueError:
+            pass
+        else:
+            files.append(x)
+        
+    # Sort the globbed files based on the index value.
     def file_sort(x, y):
-        x1 = float(re.sub(tail + '$', '', re.sub('^'+head, '', x)))
-        y1 = float(re.sub(tail + '$', '', re.sub('^'+head, '', y)))
+        x1 = _get_index(x)
+        y1 = _get_index(y)
         if x1 > y1:
             return 1
         elif y1 > x1:
@@ -745,7 +771,7 @@ class CutPlaneModule (Module):
         debug ("In CutPlaneModule::__init ()")
         Module.__init__ (self, mod_m)
         # this should be a vtkPlane
-        self.plane = vtkpython.vtkPlane ()
+        self.plane = vtk.vtkPlane ()
         self.step_var = Tkinter.DoubleVar ()
         self.n_step_var = Tkinter.IntVar ()
         self.resoln_var = Tkinter.DoubleVar ()
