@@ -11,11 +11,11 @@ Copyright (c) 2003, Prabhu Ramachandran.
 """
 
 __author__ = "Prabhu Ramachandran <prabhu_r@users.sf.net>"
-__version__ = "$Revision: 1.2 $"
-__date__ = "$Date: 2004/07/06 04:29:30 $"
+__version__ = "$Revision: 1.3 $"
+__date__ = "$Date: 2005/08/02 18:26:24 $"
 
 import Base.Objects, Common
-import vtkpython
+import vtk
 import vtkPipeline.ConfigVtkObj
 import Tkinter
 import math
@@ -30,8 +30,8 @@ class CutPlane (Base.Objects.Filter):
 
     def initialize (self):
         debug ("In CutPlane::initialize ()")
-        self.plane = vtkpython.vtkPlane ()
-        self.fil = vtkpython.vtkCutter ()
+        self.plane = vtk.vtkPlane ()
+        self.fil = vtk.vtkCutter ()
         out = self.prev_fil.GetOutput()
         self.fil.SetInput (out)
         self.fil.SetCutFunction (self.plane)
