@@ -11,12 +11,12 @@ Copyright (c) 2001-2002, Prabhu Ramachandran.
 """
 
 __author__ = "Prabhu Ramachandran <prabhu_r@users.sf.net>"
-__version__ = "$Revision: 1.5 $"
-__date__ = "$Date: 2004/07/06 04:29:30 $"
+__version__ = "$Revision: 1.6 $"
+__date__ = "$Date: 2005/08/02 18:26:25 $"
 
 import Base.Objects, Common
 import Tkinter
-import vtkpython
+import vtk
 import vtkPipeline.vtkMethodParser
 
 debug = Common.debug
@@ -29,7 +29,7 @@ class ExtractVectorComponents (Base.Objects.Filter):
 
     def initialize (self):
         debug ("In ExtractVectorComponents::initialize ()")
-        self.fil = vtkpython.vtkExtractVectorComponents ()
+        self.fil = vtk.vtkExtractVectorComponents ()
         self.fil.SetInput (self.prev_fil.GetOutput ())
         self.comp_var = Tkinter.IntVar ()
         self.comp_var.set (0)
