@@ -13,12 +13,12 @@ Copyright (c) 2003, Prabhu Ramachandran.
 """
 
 __author__ = "Prabhu Ramachandran <prabhu_r@users.sf.net>"
-__version__= "$Revision: 1.3 $"
-__date__   = "$Date: 2004/08/14 13:11:18 $"
+__version__= "$Revision: 1.4 $"
+__date__   = "$Date: 2005/08/02 18:26:25 $"
 
 import Base.Objects, Common
 import Tkinter
-import vtkpython
+import vtk
 import vtkPipeline.ConfigVtkObj
 import tkSimpleDialog
 import sys
@@ -45,10 +45,10 @@ def get_valid_class(name):
         msg = "No class chosen, cannot create filter!"
         raise Base.Objects.ModuleException, msg
         
-    if not hasattr(vtkpython, name):
+    if not hasattr(vtk, name):
         msg = "Unable to find VTK class named: '%s'"%name
         raise Base.Objects.ModuleException, msg
-    klass = getattr(vtkpython, name)
+    klass = getattr(vtk, name)
     try:
         obj = klass()
     except TypeError:
