@@ -12,12 +12,12 @@ Copyright (c) 2001-2002, Prabhu Ramachandran.
 """
 
 __author__ = "Prabhu Ramachandran <prabhu_r@users.sf.net>"
-__version__ = "$Revision: 1.3 $"
-__date__ = "$Date: 2002/06/06 12:02:52 $"
+__version__ = "$Revision: 1.4 $"
+__date__ = "$Date: 2005/08/02 18:26:25 $"
 
 import PolyDataNormals
 import Common
-import vtkpython
+import vtk
 
 debug = Common.debug
 
@@ -31,6 +31,6 @@ class WarpScalar (PolyDataNormals.PolyDataNormals):
 
     def initialize (self):
         debug ("In WarpScalar::initialize ()")
-        self.fil = vtkpython.vtkWarpScalar ()
+        self.fil = vtk.vtkWarpScalar ()
         self._set_input ()
         self.fil.Update ()
