@@ -15,8 +15,8 @@ Copyright (c) 2001-2005, Prabhu Ramachandran.
 """
 
 __author__ = "Prabhu Ramachandran <prabhu_r@users.sf.net>"
-__version__ = "$Revision: 1.43 $"
-__date__ = "$Date: 2005/02/01 16:16:06 $"
+__version__ = "$Revision: 1.51 $"
+__date__ = "$Date: 2005/08/24 10:45:20 $"
 
 import os, traceback, glob, sys, string
 import Tkinter, tkFileDialog, tkMessageBox, tkColorChooser
@@ -27,7 +27,7 @@ import Sources.VtkXMLDataReader
 import Sources.VtkEnSightReader
 import Misc.RenderWindow
 import vtkPipeline.vtkPipeline
-import vtkpython
+import vtk
 from __version__ import version
 
 
@@ -378,6 +378,67 @@ class MayaVi:
                 Common.state.force_idle ()
             return name
         
+    def open_user(self, rdr_name, filename, config=1, *args, **kw_args):
+        """Opens a file using a user defined reader.
+
+        Note that this method assumes that the class name of the
+        reader is the same as the name of the Python module that
+        defines the reader.  The code also tries to check for a
+        'filetypes' attribute in the module.  This is used when the
+        file-dialog is opened.
+
+
+        Input Arguments:
+
+          rdr_name -- A string containing a valid Reader name.
+                      If the reader name has a 'User.' prepended to it
+                      then the module is first searched for in the
+                      user specified search paths and then in the
+                      default system directories.  The search path can
+                      be specified like PYTHONPATH, and is a
+                      ':'-separated string.  ~, ~user and $VAR are all
+                      expanded.  The path can be specified in the
+                      Preferences dialog.
+
+          filename -- The file name of the file to open.
+          
+          config -- if non-zero it pops up the configuration GUI for
+                    the Filter after it is loaded.
+
+          args -- optional non-keyword arguments, these are simply
+                  passed to the module constructor.
+          
+          kw_args -- optional keyword arguments, these are simply
+                     passed to the module constructor.
+        """
+        debug ("In MayaVi::open_user ()")
+	if not filename or not rdr_name:
+	  return
+        try:
+	    rw = self.gui.get_render_window()
+            _imp = Common.mod_fil_import
+            if rdr_name[:5] == 'User.':
+                rdr_scr = _imp('Sources', rdr_name[5:], globals(),
+                               locals(), 1)
+                rdr_name = rdr_name[5:]
+            else:
+                rdr_scr = _imp('Sources', rdr_name, globals(),
+                               locals(), 0)
+	    data = getattr(rdr_scr, rdr_name)(rw, *args, **kw_args)
+	    dvm = Base.DataVizManager.DataVizManager (data, rw)
+	    self.add_dvm(dvm)
+            Common.state.busy ()
+            data.initialize (filename)
+            self.gui.update_label ()
+            Common.state.idle ()
+            if config:
+                data.configure (self.gui.root)
+	    dvm.add_module_mgr_gui()
+            return data
+        except Exception, v:
+            exception ()
+            Common.state.force_idle ()
+
     def add_dvm (self, dvm): 
         """ Add a new DataVizManager instance."""
         debug ("In MayaVi::add_dvm ()")
@@ -670,13 +731,19 @@ class MayaVi:
             dvm = self.data_viz_mgr[self.cur_dvm_name]
             data_src = dvm.get_data_source ()
             d_name = data_src.__class__.__name__
-            
-            self._write_msg (file, "### %s ###\n"%d_name)
-            file.write (d_name+'\n')
-            data_src.save_config (file)
-            self._write_msg (file, "### End of %s ###\n"%d_name)
+            if data_src.__module__.find('Sources.') > -1:
+                # standard source.                
+                self._write_msg (file, "### %s ###\n"%d_name)
+                file.write (d_name+'\n')
+                data_src.save_config (file)
+                self._write_msg (file, "### End of %s ###\n"%d_name)
+            else:
+                self._write_msg (file, "### User.%s ###\n"%d_name)
+                file.write ("User.%s\n"%d_name)            
+                data_src.save_config (file)
+                self._write_msg (file, "### End of User.%s ###\n"%d_name)
 
-            dvm.save_config (file)        
+            dvm.save_config (file)
             self._write_msg (file, "### End of %s ###\n"%self.cur_dvm_name)
             self._write_msg (file, "### End of DataVizManagers ###\n")
             self._write_msg (file, "### RenderWindow ###\n")
@@ -706,10 +773,18 @@ class MayaVi:
                 dvm = self.data_viz_mgr[dvm_name]
                 data_src = dvm.get_data_source ()
                 d_name = data_src.__class__.__name__
-                self._write_msg (file, "### %s ###\n"%d_name)
-                file.write (d_name+'\n')
-                data_src.save_config (file)
-                self._write_msg (file, "### End of %s ###\n"%d_name)
+                if data_src.__module__.find('Sources.') > -1:
+                    # standard source.                
+                    self._write_msg (file, "### %s ###\n"%d_name)
+                    file.write (d_name+'\n')
+                    data_src.save_config (file)
+                    self._write_msg (file, "### End of %s ###\n"%d_name)
+                else:
+                    self._write_msg (file, "### User.%s ###\n"%d_name)
+                    file.write ("User.%s\n"%d_name)            
+                    data_src.save_config (file)
+                    self._write_msg (file, "### End of User.%s ###\n"%d_name)
+
                 dvm.save_config (file)
                 self._write_msg (file, "### End of %s ###\n"%dvm_name)
             self._write_msg (file, "### End of DataVizManagers ###\n")
@@ -742,7 +817,13 @@ class MayaVi:
                 self._read_msg (file)
                 self._read_msg (file)
                 name = file.readline ()[:-1]
-                data_src = eval ("Sources.%s.%s(rw)"%(name, name))
+                if name[:5] == 'User.':
+                    name = name[5:]
+                    data_mod = Common.mod_fil_import('Sources', name,
+                                                     globals(), locals(), 1)
+                    data_src = eval ("data_mod.%s(rw)"%name)
+                else:
+                    data_src = eval ("Sources.%s.%s(rw)"%(name, name))
                 data_src.load_config (file)
                 self._read_msg (file)
                 dvm = Base.DataVizManager.DataVizManager (data_src, rw)
@@ -823,7 +904,7 @@ class DocHelper:
             base_dir = os.path.abspath (home)
 
         # online docs -- default.
-        self.guide = "http://mayavi.sourceforge.net/docs/guide/book1.html"
+        self.guide = "http://mayavi.sourceforge.net/docs/guide/index.html"
         # for binaries and inside the source dir (CVS) based installs
         guide_dirs = [os.path.join (base_dir, 'doc')]
         # Debian
@@ -832,7 +913,7 @@ class DocHelper:
         guide_dirs.extend (glob.glob ("/usr/share/doc/MayaVi*"))
         # Add more relavant directories if the docs are elsewhere.
         for d in guide_dirs:
-            g = os.path.join (d, 'guide', 'book1.html')
+            g = os.path.join (d, 'guide', 'index.html')
             if os.path.isfile (g):
                 self.guide = g
                 break
@@ -885,20 +966,28 @@ class MayaViTkGUI:
     """ This is the main application and creates the GUI and controls
     everything."""
 
-    def __init__ (self, master, geometry=None):
+    def __init__ (self, master, geometry=None, root=None):
         """
         Constructor for the main MayaVi GUI window.
         
         Keyword Arguments:
 
         master -- Toplevel parentwindow.        
+
         geometry -- The geometry of the main window in standard X
         fashion (WxH+X+Y).
 
+        root -- The root window into which MayaVi's GUI should be
+        created.  This defaults to `None` in which case a new
+        `Tkinter.Toplevel` widget is created.
+
         """
         debug ("In MayaViTkGUI::__init__ ()")
         self.master = master
-        self.root = Tkinter.Toplevel (master)        
+        if not root:
+            self.root = Tkinter.Toplevel (master)
+        else:
+            self.root = root
         self.mayavi = MayaVi (self)
         self.doc_helper = DocHelper ()
         
@@ -929,6 +1018,7 @@ class MayaViTkGUI:
         
         self.module_var = Tkinter.StringVar ()
         self.filter_var = Tkinter.StringVar ()
+        self.reader_var = Tkinter.StringVar ()
 
         self.vrml_var = Tkinter.StringVar ()
 
@@ -976,7 +1066,7 @@ class MayaViTkGUI:
         self.menu.add_cascade (label="Help", menu=self.help_menu,
                                underline=0)
 
-            ## File menus
+        ## File menus
         self.file_menu.add_command (label="New Window", underline=0, 
                                     command=self.new_window)        
 
@@ -1007,31 +1097,7 @@ class MayaViTkGUI:
                                     command=self.close_all)
         self.file_menu.add_command (label="Exit", underline=1, 
                                     command=self.quit)
-        
-        ## Open menu
-        self.open_menu.add_command (label="VTK file", underline=0,
-                                    command=self.open_vtk)
-        self.open_menu.add_command (label="VTK XML file", underline=4,
-                                    command=self.open_vtk_xml)
-        self.open_menu.add_command (label="EnSight case file", underline=0,
-                                    command=self.open_ensight)
-        self.pl3d_menu = Tkinter.Menu (self.open_menu, tearoff=0)
-        self.open_menu.add_cascade (label="PLOT3D file", underline=1,
-                                    menu=self.pl3d_menu)
-
-        ## HACK to support a user defined reader.
-        self.user_reader_func = None
-        try:
-            import MayaViUserReader
-            # a function that is passed self and handles file opening
-            # and setting up MayaVi for the new reader.            
-            self.user_reader_func = MayaViUserReader.user_function
-            menu_name, uline = MayaViUserReader.get_menu_data()
-            self.open_menu.add_command(label=menu_name, underline=uline,
-                                       command=lambda m=self:\
-                                       m.user_reader_func(m))
-        except ImportError:
-            pass
+	self.make_open_menu()        
 
         ## Import menu
         self.import_menu.add_command (label="VRML2 scene",
@@ -1159,6 +1225,36 @@ class MayaViTkGUI:
                                     underline=0,
                                     command=self.doc_helper.show_home_page)
 
+    def make_open_menu(self):
+        ## Open menu
+        self.open_menu.add_command (label="VTK file", underline=0,
+                                    command=self.open_vtk)
+        self.open_menu.add_command (label="VTK XML file", underline=4,
+                                    command=self.open_vtk_xml)
+        self.open_menu.add_command (label="EnSight case file", underline=0,
+                                    command=self.open_ensight)
+        self.pl3d_menu = Tkinter.Menu (self.open_menu, tearoff=0)
+        self.open_menu.add_cascade (label="PLOT3D file", underline=1,
+                                    menu=self.pl3d_menu)
+
+        ## Support for user defined readers.
+	rdr_list = find_scripts("Sources", Common.config.upath, no_base=1)
+	rdr_list.insert(0, 'User')
+	hk_list = find_hot_key(rdr_list)
+
+	self.user_reader_menu = Tkinter.Menu(self.open_menu, tearoff=0)
+	self.open_menu.add_cascade(label="User", underline=hk_list[0],
+					menu=self.user_reader_menu)
+
+	for i in range(1, len(rdr_list) ):
+	  rdr = rdr_list[i]
+	  hk = hk_list[i]
+	  self.user_reader_menu.add_radiobutton( label=rdr,
+						 value='User.'+rdr,
+						 variable=self.reader_var,
+						 indicatoron=0,
+						 underline=hk,
+						 command=self.open_user)
 
     def make_module_menu (self):
         debug ("In MayaViTkGUI::make_module_menu ()")
@@ -1422,6 +1518,143 @@ class MayaViTkGUI:
                                          ("All files", "*")])
         self.open_3ds (file_name)
 
+    def open_user_data(self, rdr_name="", obj=None, config=1,
+                       *args, **kw_args):
+        """Opens a data object using a user defined reader.
+
+        Note that this method assumes that the class name of the
+        reader is the same as the name of the Python module that
+        defines the reader.  The code also tries to check for a
+        'datatypes' attribute in the module.  This must be a list
+        specifying the supported class names of the input data types.
+        The reader must also support passing a data object instead of
+        a file name.
+
+        Input Arguments:
+
+          rdr_name -- A string containing a valid Reader name.  If
+                      this is empty, then the last value chosen via
+                      the menu is used.  If the reader name has a
+                      'User.' prepended to it then the module is first
+                      searched for in the user specified search paths
+                      and then in the default system directories.  The
+                      search path can be specified like PYTHONPATH,
+                      and is a ':'-separated string.  ~, ~user and
+                      $VAR are all expanded.  The path can be
+                      specified in the Preferences dialog.
+
+          obj -- The data object to open.  Must be of a type listed in the
+                 given readers datatypes attribute.
+
+          config -- if non-zero it pops up the configuration GUI for
+                    the Filter after it is loaded.
+
+          args -- optional non-keyword arguments, these are simply
+                  passed to the module constructor.
+
+          kw_args -- optional keyword arguments, these are simply
+                     passed to the module constructor.
+        """
+        if not rdr_name:
+            rdr_name = self.reader_var.get()
+
+        try:
+            Common.state.busy ()
+            _imp = Common.mod_fil_import
+            if rdr_name[:5] == 'User.':
+                rdr_scr = _imp('Sources', rdr_name[5:], globals(),
+                               locals(), 1)
+            else:
+                rdr_scr = _imp('Sources', rdr_name, globals(),
+                               locals(), 0)
+            Common.state.idle ()
+        except Exception, v:
+            exception ()
+            Common.state.force_idle ()
+            return None
+
+        if rdr_scr.__dict__.has_key('datatypes') and \
+               obj.__class__.__name__ in rdr_scr.datatypes:
+            return self.mayavi.open_user (rdr_name, obj, config,
+                                          *args, **kw_args)
+        else:
+            msg = "Sorry, the datatype: %s,"\
+                  " is not supported by the reader."%obj.__class__.__name__
+            print_err (msg)
+            return None
+
+    def open_user(self, rdr_name="", filename="", config=1, *args, **kw_args):
+        """Opens a file using a user defined reader.
+
+        Note that this method assumes that the class name of the
+        reader is the same as the name of the Python module that
+        defines the reader.  The code also tries to check for a
+        'filetypes' attribute in the module.  This is used when the
+        file-dialog is opened.
+
+
+        Input Arguments:
+
+          rdr_name -- A string containing a valid Reader name.  If
+                      this is empty, then the last value chosen via
+                      the menu is used.  If the reader name has a
+                      'User.' prepended to it then the module is first
+                      searched for in the user specified search paths
+                      and then in the default system directories.  The
+                      search path can be specified like PYTHONPATH,
+                      and is a ':'-separated string.  ~, ~user and
+                      $VAR are all expanded.  The path can be
+                      specified in the Preferences dialog.
+
+          filename -- The file name of the file to open.  If not
+                      specified a dialog box will pop up that lets you
+                      choose the file.
+          
+          config -- if non-zero it pops up the configuration GUI for
+                    the Filter after it is loaded.
+
+          args -- optional non-keyword arguments, these are simply
+                  passed to the module constructor.
+          
+          kw_args -- optional keyword arguments, these are simply
+                     passed to the module constructor.
+        """
+        debug ("In MayaViTkGUI::open_user ()")
+
+        if not rdr_name:
+            rdr_name = self.reader_var.get()
+
+        if not filename:
+            # If no filename was specified try and open a dialog to
+            # choose the file.
+            try:
+                Common.state.busy ()
+                _imp = Common.mod_fil_import
+                if rdr_name[:5] == 'User.':
+                    rdr_scr = _imp('Sources', rdr_name[5:], globals(),
+                                   locals(), 1)
+                else:
+                    rdr_scr = _imp('Sources', rdr_name, globals(),
+                                   locals(), 0)
+                Common.state.idle ()
+
+            except Exception, v:
+                exception ()
+                Common.state.force_idle ()
+
+            if rdr_scr.__dict__.has_key('filetypes'):
+                rdr_filetypes = rdr_scr.filetypes
+            else:
+                rdr_filetypes = []
+            rdr_filetypes.append(("All files", "*"))
+            filename = tk_fopen (title="Open Data file",
+                                 initialdir=Common.config.initial_dir,
+                                 filetypes=rdr_filetypes)
+
+        if check_file (filename):
+            return self.mayavi.open_user (rdr_name, filename, config, 
+                                          *args, **kw_args)
+
     def add_dvm (self, dvm_name): 
         """ Add a new DataVizManager to the GUI list."""
         debug ("In MayaViTkGUI::add_dvm ()")
