@@ -15,25 +15,25 @@ Copyright (c) 2002, Raymond C. Maple and Prabhu Ramachandran.
 """
 
 __author__ = "Raymond C. Maple <mapler@erinet.com>"
-__version__ = "$Revision: 1.5 $"
-__date__ = "$Date: 2003/10/22 20:23:55 $"
+__version__ = "$Revision: 1.6 $"
+__date__ = "$Date: 2005/08/02 18:26:25 $"
 __credits__ = """This module was entirely written by Raymond Maple.
 It was later modified by Prabhu Ramachandran and made suitable for
 inclusion in MayaVi."""
 
 
+import vtk
 import Tkinter
-from vtkRenderWidget import vtkTkRenderWidget
+from vtk.tk.vtkTkRenderWidget import vtkTkRenderWidget
 from tkColorChooser import askcolor
 from math import pi, sin, cos, atan2, sqrt
-import vtkpython
 import vtkPipeline.vtkMethodParser
 import string
 import sys
 
 class Light:
     def __init__(self):
-        self.source = vtkpython.vtkLight()
+        self.source = vtk.vtkLight()
         self.glyph = LightGlyph()
         self.el = 0
         self.az = 0
@@ -131,39 +131,39 @@ class LightGlyph:
         nverts = 10
             
         # First build the cone portion
-        cone = vtkpython.vtkConeSource()
+        cone = vtk.vtkConeSource()
         cone.SetResolution(nverts)
         cone.SetRadius(.08)
         cone.SetHeight(.2)
         cone.CappingOff()
     
-        coneMapper = vtkpython.vtkPolyDataMapper()
+        coneMapper = vtk.vtkPolyDataMapper()
         coneMapper.SetInput(cone.GetOutput())
 
         # Now take care of the capping polygon
-        pts = vtkpython.vtkPoints()
+        pts = vtk.vtkPoints()
         pts.SetNumberOfPoints(nverts)
     
         for i in range(0, nverts):
             theta = 2*i*pi/nverts + pi/2
             pts.InsertPoint(i,0.8,.08*sin(theta),.08*cos(theta))
         
-        poly = vtkpython.vtkPolygon()
+        poly = vtk.vtkPolygon()
         poly.GetPointIds().SetNumberOfIds(nverts)
         for i in range(0, nverts):
             poly.GetPointIds().SetId(i, i)
         
-        pdata = vtkpython.vtkPolyData()
+        pdata = vtk.vtkPolyData()
         pdata.Allocate(1, 1)
         pdata.InsertNextCell(poly.GetCellType(), poly.GetPointIds())
         pdata.SetPoints(pts)
-        capmapper = vtkpython.vtkPolyDataMapper()
+        capmapper = vtk.vtkPolyDataMapper()
         capmapper.SetInput(pdata)
 
         self.el = 0.0
         self.az = 0.0
 
-        self.coneActor = vtkpython.vtkActor()
+        self.coneActor = vtk.vtkActor()
         self.coneActor.SetMapper(coneMapper)
         self.coneActor.SetPosition(0.9,0,0)
         self.coneActor.SetOrigin(-0.9,0,0)
@@ -171,7 +171,7 @@ class LightGlyph:
         self.coneActor.GetProperty().SetAmbient(.1)
         self.coneActor.RotateY(-90)
 
-        self.capActor = vtkpython.vtkActor()
+        self.capActor = vtk.vtkActor()
         self.capActor.SetMapper(capmapper)
         self.capActor.GetProperty().SetAmbientColor(1, 1,0)
         self.capActor.GetProperty().SetAmbient(1)
@@ -208,7 +208,7 @@ def ArcActor(from_, to, rad=1.0, axis='z', n=20):
     to = to*pi/180
     angle = to - from_
     
-    ppnts = vtkpython.vtkPoints()
+    ppnts = vtk.vtkPoints()
     ppnts.SetNumberOfPoints(n)
     
     for i in range(0, n):
@@ -220,20 +220,20 @@ def ArcActor(from_, to, rad=1.0, axis='z', n=20):
         elif axis == 'z':
             ppnts.InsertPoint(i, cos(theta), sin(theta),0.0)
             
-    pline = vtkpython.vtkPolyLine()
+    pline = vtk.vtkPolyLine()
     pline.GetPointIds().SetNumberOfIds(n)
     for i in range(0, n):
         pline.GetPointIds().SetId(i, i)
 
-    pdata = vtkpython.vtkPolyData()
+    pdata = vtk.vtkPolyData()
     pdata.Allocate(1, 1)
     pdata.InsertNextCell(pline.GetCellType(), pline.GetPointIds())
     pdata.SetPoints(ppnts)
     
-    mapper = vtkpython.vtkPolyDataMapper()
+    mapper = vtk.vtkPolyDataMapper()
     mapper.SetInput(pdata)
     
-    actor = vtkpython.vtkActor()
+    actor = vtk.vtkActor()
     actor.SetMapper(mapper)
     actor.GetProperty().SetColor(1,0,0)
     return actor
@@ -522,7 +522,7 @@ class LightTool(Tkinter.Toplevel):
             l.save()
         
         self.gfxwin = vtkTkRenderWidget(self, width=220, height=200)
-        self.ren = vtkpython.vtkRenderer()
+        self.ren = vtk.vtkRenderer()
 
         self.switchbank = Tkinter.Frame(self)
         self.leftarrow = Tkinter.BitmapImage(data=self.left_data)
@@ -604,7 +604,7 @@ class LightTool(Tkinter.Toplevel):
 
         self.gfxwin.GetRenderWindow().AddRenderer(self.ren)
         self.ren.SetBackground(0.0,0.0,0.0)
-        self.picker = vtkpython.vtkCellPicker()
+        self.picker = vtk.vtkCellPicker()
         self.picker.SetTolerance(0.0005)
 
         for l in lights:
@@ -769,7 +769,7 @@ class LightManager:
 
         # this hack seems to be necessary under VTK 4.x too.
 
-        dumblight = vtkpython.vtkLight()
+        dumblight = vtk.vtkLight()
         dumblight.SwitchOff()
         ren.AddLight(dumblight)
         for l in lights:
@@ -841,7 +841,7 @@ def main():
     renwidget = vtkTkRenderWidget(root,width=300,height=300)
     renwidget.pack()
     renWin = renwidget.GetRenderWindow()
-    ren1 = vtkpython.vtkRenderer()
+    ren1 = vtk.vtkRenderer()
     renWin.AddRenderer( ren1 )
 
     def halt(event=None):
@@ -858,14 +858,14 @@ def main():
     renwidget.bind("<e>", halt)
     root.protocol("WM_DELETE_WINDOW", halt)
 
-    sphere = vtkpython.vtkSphereSource()
-    sphereMapper = vtkpython.vtkPolyDataMapper()
+    sphere = vtk.vtkSphereSource()
+    sphereMapper = vtk.vtkPolyDataMapper()
     sphereMapper.SetInput( sphere.GetOutput() )
-    sphereActor = vtkpython.vtkLODActor()
+    sphereActor = vtk.vtkLODActor()
     sphereActor.SetMapper( sphereMapper )
 
-    cone = vtkpython.vtkConeSource()
-    glyph = vtkpython.vtkGlyph3D()
+    cone = vtk.vtkConeSource()
+    glyph = vtk.vtkGlyph3D()
     glyph.SetInput( sphere.GetOutput() )
     glyph.SetSource(cone.GetOutput())
     glyph.SetVectorModeToUseNormal()
@@ -873,9 +873,9 @@ def main():
     glyph.SetScaleFactor( 0.25 )
     glyph.ReleaseDataFlagOn()
 
-    spikeMapper = vtkpython.vtkPolyDataMapper()
+    spikeMapper = vtk.vtkPolyDataMapper()
     spikeMapper.SetInput( glyph.GetOutput() )
-    spikeActor = vtkpython.vtkLODActor()
+    spikeActor = vtk.vtkLODActor()
     spikeActor.SetMapper( spikeMapper )
 
     ren1.AddActor( sphereActor )
