@@ -10,14 +10,15 @@ Copyright (c) 2001-2002, Prabhu Ramachandran.
 """
 
 __author__ = "Prabhu Ramachandran <prabhu_r@users.sf.net>"
-__version__ = "$Revision: 1.14 $"
-__date__ = "$Date: 2004/07/06 04:29:30 $"
+__version__ = "$Revision: 1.17 $"
+__date__ = "$Date: 2005/08/02 18:26:25 $"
 
 import Tkinter, tkFileDialog, types
-import vtkpython, os
+import vtk, os
 import Common, Base.Objects
 import vtkPipeline.vtkMethodParser
 import Lut_Editor
+import GradientEditor
 
 tk_fopen = tkFileDialog.askopenfilename
 debug = Common.debug
@@ -123,7 +124,7 @@ class LutHandler (Base.Objects.VizObject):
     def init_lut (self): 
         "Set up the default LookupTable. Defaults to a blue to red table."
         debug ("In LutHandler::init_lut ()")
-        self.lut = vtkpython.vtkLookupTable ()
+        self.lut = vtk.vtkLookupTable ()
         self.lut.SetHueRange (0.667, 0.0)
         self.lut.SetNumberOfTableValues (self.n_color_var.get ())
         self.lut.SetRampToSQRT()
@@ -132,18 +133,23 @@ class LutHandler (Base.Objects.VizObject):
     def init_scalar_bar (self): 
         "Sets up the default scalar bar."
         debug ("In LutHandler::init_scalar_bar ()")
-        self.sc_bar = vtkpython.vtkScalarBarActor ()
+        self.sc_bar = vtk.vtkScalarBarActor ()
         self.sc_bar.SetLookupTable (self.lut)
         self.sc_bar.GetPositionCoordinate ().SetCoordinateSystemToNormalizedViewport ()
         self.set_horizontal ()
         self.sc_bar.SetVisibility (0)
         self.sc_bar.SetNumberOfLabels (8)
+        fg_color = Common.config.fg_color
+        self.sc_bar.GetProperty ().SetColor(fg_color)
         if hasattr(self.sc_bar, "GetTitleTextProperty"):
-            self.sc_bar.GetTitleTextProperty().SetShadow (self.shadow_on_var.get ())
-            self.sc_bar.GetLabelTextProperty().SetShadow (self.shadow_on_var.get ())
+            ttp = self.sc_bar.GetTitleTextProperty()
+            ltp = self.sc_bar.GetLabelTextProperty()
+            ttp.SetShadow (self.shadow_on_var.get ())
+            ltp.SetShadow (self.shadow_on_var.get ())
+            ttp.SetColor(fg_color)
+            ltp.SetColor(fg_color)
         else:
             self.sc_bar.SetShadow (self.shadow_on_var.get ())
-        self.sc_bar.GetProperty ().SetColor(*Common.config.fg_color)
         self.module_mgr.get_render_window ().add_actors (self.sc_bar)
             
     def save_config_to_dict (self, base_file_name):
@@ -298,11 +304,20 @@ class LutHandler (Base.Objects.VizObject):
                               self.sc_bar.GetPosition2Coordinate())):
                 p.load (obj, inp[key])
 
+        if hasattr(self.sc_bar, "GetTitleTextProperty"):
+            color = self.sc_bar.GetProperty().GetColor()
+            self.sc_bar.GetTitleTextProperty().SetColor(color)
+            self.sc_bar.GetLabelTextProperty().SetColor(color)
+
         self._setup_config(file_name)
 
     def config_changed (self): 
         debug ("In LutHandler::config_changed ()")
-        self.sc_bar.GetProperty ().SetColor(*Common.config.fg_color)
+        color = Common.config.fg_color
+        self.sc_bar.GetProperty ().SetColor(color)
+        if hasattr(self.sc_bar, "GetTitleTextProperty"):
+            self.sc_bar.GetTitleTextProperty().SetColor(color)
+            self.sc_bar.GetLabelTextProperty().SetColor(color)
 
     def set_horizontal (self): 
         "Makes the legend horizontal with default values."
@@ -460,7 +475,11 @@ class LutHandler (Base.Objects.VizObject):
                               command=self.edit_lut)
         but.grid (row=rw, column=0, pady=2)
         rw += 1
-
+        but = Tkinter.Button (frame, text="Create Lookup Table",
+                              command=self.create_lut)
+        but.grid (row=rw, column=0, pady=2)
+        rw += 1
+        
         rb = Tkinter.Radiobutton (frame, text='blue-red colormap',
                                   value=1, variable=self.lut_var,
                                   command=self.change_lut)
@@ -607,6 +626,14 @@ class LutHandler (Base.Objects.VizObject):
         self.file_name = app.run ()
         self._make_transparent_lut ()
 
+    def create_lut (self, event=None): 
+        debug ("In LutHandler::create_lut ()")
+        self.lut_var.set (0)
+        def OnChangeColorTable():
+            self.renwin.Render()
+        cge = GradientEditor.GradientEditor(self.root, self.lut,
+                                            OnChangeColorTable)
+
     def change_lut (self): 
         "Changes the lookup table to use."
         debug ("In LutHandler::change_lut ()")
