@@ -435,14 +435,14 @@ class Lut_Editor:
 
 
 if __name__ == "__main__":
-    import vtkpython 
+    import vtk 
     root = Tkinter.Tk ()
     root.withdraw ()
     app = Lut_Editor (root)
     # create a new lookup table and edit it.
     # need this to create a new table from a hue range and also to set
     # the lut.
-    lt = vtkpython.vtkLookupTable ()
+    lt = vtk.vtkLookupTable ()
     lt.SetHueRange (0.66667, 0.0)
     app.edit_lut (lt)
     app.run ()
