@@ -12,11 +12,12 @@ Copyright (c) 2001-2003, Prabhu Ramachandran.
 """
 
 __author__ = "Prabhu Ramachandran <prabhu_r@users.sf.net>"
-__version__ = "$Revision: 1.25 $"
-__date__ = "$Date: 2004/07/06 04:29:30 $"
+__version__ = "$Revision: 1.28 $"
+__date__ = "$Date: 2005/08/02 18:26:25 $"
 
 import Tkinter, tkFileDialog, tkMessageBox, tkSimpleDialog
-import vtkpython, vtkRenderWidget
+import vtk
+from vtk.tk import vtkTkRenderWidget
 import Common, Base.Objects
 import types, os
 import vtkPipeline.ConfigVtkObj
@@ -81,18 +82,18 @@ class RenderWindow (Base.Objects.VizObject):
         self._do_render = 1
         stereo = Common.config.stereo
         if stereo:
-            tkw = vtkRenderWidget.vtkTkRenderWidget (self.frame, width=600,
-                                                     height=505, stereo=1)
+            tkw = vtkTkRenderWidget.vtkTkRenderWidget (self.frame, width=600,
+                                                       height=505, stereo=1)
         else:
-            tkw = vtkRenderWidget.vtkTkRenderWidget (self.frame, width=600,
-                                                     height=505)
+            tkw = vtkTkRenderWidget.vtkTkRenderWidget (self.frame, width=600,
+                                                       height=505)
         self.tkwidget = tkw
         self.tkwidget.pack (expand='true',fill='both')
         #self.tkwidget.bind ("<KeyPress-q>", self.quit)
         # disabling surface and wireframe toggling.
         self.tkwidget.unbind ("<KeyPress-s>")
         self.tkwidget.unbind ("<KeyPress-w>")
-        self.ren = vtkpython.vtkRenderer ()
+        self.ren = vtk.vtkRenderer ()
         self.ren.TwoSidedLightingOn ()
         self.renwin = self.tkwidget.GetRenderWindow ()
         self.renwin.AddRenderer (self.ren)
@@ -237,11 +238,11 @@ class RenderWindow (Base.Objects.VizObject):
                                              ("All files", "*")])
         if len (file_name) != 0:
             Common.state.busy ()
-            w2if = vtkpython.vtkWindowToImageFilter ()
+            w2if = vtk.vtkWindowToImageFilter ()
             w2if.SetMagnification (Common.config.magnification)
             self.lift ()
             w2if.SetInput (self.renwin)
-            ex = vtkpython.vtkPostScriptWriter ()
+            ex = vtk.vtkPostScriptWriter ()
             ex.SetFileName (file_name)
             ex.SetInput (w2if.GetOutput ())
             ex.Write ()
@@ -277,11 +278,11 @@ class RenderWindow (Base.Objects.VizObject):
                                              ("All files", "*")])
         if len (file_name) != 0:
             Common.state.busy ()
-            w2if = vtkpython.vtkWindowToImageFilter ()
+            w2if = vtk.vtkWindowToImageFilter ()
             w2if.SetMagnification (Common.config.magnification)
             self.lift ()
             w2if.SetInput (self.renwin)
-            ex = vtkpython.vtkBMPWriter ()
+            ex = vtk.vtkBMPWriter ()
             ex.SetFileName (file_name)
             ex.SetInput (w2if.GetOutput ())
             ex.Write () 
@@ -298,11 +299,11 @@ class RenderWindow (Base.Objects.VizObject):
                                              ("All files", "*")])
         if len (file_name) != 0:
             Common.state.busy ()
-            w2if = vtkpython.vtkWindowToImageFilter ()
+            w2if = vtk.vtkWindowToImageFilter ()
             w2if.SetMagnification (Common.config.magnification)
             self.lift ()
             w2if.SetInput (self.renwin)
-            ex = vtkpython.vtkTIFFWriter ()
+            ex = vtk.vtkTIFFWriter ()
             ex.SetFileName (file_name)
             ex.SetInput (w2if.GetOutput ())
             ex.Write () 
@@ -312,7 +313,7 @@ class RenderWindow (Base.Objects.VizObject):
         """Requires VTK 4 to work."""
         debug ("In RenderWindow::save_png ()")
         try:
-            ex = vtkpython.vtkPNGWriter ()
+            ex = vtk.vtkPNGWriter ()
         except AttributeError:
             msg = "Saving to a PNG file is not supported by your "\
                   "version of VTK.  Versions 4.0 and above support this."
@@ -326,11 +327,11 @@ class RenderWindow (Base.Objects.VizObject):
                                              ("All files", "*")])
         if len (file_name) != 0:
             Common.state.busy ()
-            w2if = vtkpython.vtkWindowToImageFilter ()
+            w2if = vtk.vtkWindowToImageFilter ()
             w2if.SetMagnification (Common.config.magnification)
             self.lift ()
             w2if.SetInput (self.renwin)
-            ex = vtkpython.vtkPNGWriter ()
+            ex = vtk.vtkPNGWriter ()
             ex.SetFileName (file_name)
             ex.SetInput (w2if.GetOutput ())
             ex.Write () 
@@ -342,7 +343,7 @@ class RenderWindow (Base.Objects.VizObject):
         valid, the progressive arguments toggles progressive jpegs."""
         debug ("In RenderWindow::save_jpg ()")
         try:
-            ex = vtkpython.vtkJPEGWriter()
+            ex = vtk.vtkJPEGWriter()
         except AttributeError:
             msg = "Saving to a JPEG file is not supported by your "\
                   "version of VTK.  Versions 4.0 and above support this."
@@ -363,11 +364,11 @@ class RenderWindow (Base.Objects.VizObject):
                 else:
                     return
             Common.state.busy ()
-            w2if = vtkpython.vtkWindowToImageFilter ()
+            w2if = vtk.vtkWindowToImageFilter ()
             w2if.SetMagnification (Common.config.magnification)
             self.lift ()
             w2if.SetInput (self.renwin)
-            ex = vtkpython.vtkJPEGWriter ()
+            ex = vtk.vtkJPEGWriter ()
             ex.SetQuality (quality)
             ex.SetProgressive (progressive)
             ex.SetFileName (file_name)
@@ -386,7 +387,7 @@ class RenderWindow (Base.Objects.VizObject):
                                              ("All files", "*")])
         if len (file_name) != 0:
             Common.state.busy ()
-            ex = vtkpython.vtkIVExporter ()
+            ex = vtk.vtkIVExporter ()
             self.lift ()
             ex.SetInput (self.renwin)
             ex.SetFileName (file_name)
@@ -403,7 +404,7 @@ class RenderWindow (Base.Objects.VizObject):
                                              ("All files", "*")])
         if len (file_name) != 0:
             Common.state.busy ()
-            ex = vtkpython.vtkVRMLExporter ()
+            ex = vtk.vtkVRMLExporter ()
             self.lift ()
             ex.SetInput (self.renwin)
             ex.SetFileName (file_name)
@@ -415,7 +416,7 @@ class RenderWindow (Base.Objects.VizObject):
         work."""        
         debug ("In RenderWindow::save_oogl ()")
         try:
-            ex = vtkpython.vtkOOGLExporter ()
+            ex = vtk.vtkOOGLExporter ()
         except AttributeError:
             msg = "Saving to a Geomview OOGL file is not supported by "\
                   "your version of VTK.  Versions 4.0 and above "\
@@ -431,7 +432,7 @@ class RenderWindow (Base.Objects.VizObject):
                                               ("All files", "*")])
         if len (file_name) != 0:
             Common.state.busy ()
-            ex = vtkpython.vtkOOGLExporter ()
+            ex = vtk.vtkOOGLExporter ()
             self.lift ()
             ex.SetInput (self.renwin)
             ex.SetFileName (file_name)
@@ -469,17 +470,75 @@ class RenderWindow (Base.Objects.VizObject):
                 bg = tkMessageBox.askyesno ("Background On?", message=msg)
             Common.state.busy ()
             f_pref = os.path.splitext (file_name)[0]
-            ex = vtkpython.vtkRIBExporter ()
+            ex = vtk.vtkRIBExporter ()
             ex.SetFilePrefix (f_pref)
             ex.SetTexturePrefix (f_pref + "_tex")
             self.lift ()
+            
+            # The vtkRIBExporter is broken in respect to VTK light
+            # types.  Therefore we need to convert all lights into
+            # scene lights before the save and later convert them
+            # back.
+
+            ########################################
+            # Internal functions
+            def x3to4(x):
+                # convert 3-vector to 4-vector (w=1 -> point in space)
+                return (x[0], x[1], x[2], 1.0 )
+            def x4to3(x):
+                # convert 4-vector to 3-vector
+                return (x[0], x[1], x[2])
+            def for_each_light(renderer, callback):
+                # invoke callback(light) for all lights belonging to renderer
+                lightcollection = renderer.GetLights()
+                lightcollection.InitTraversal()
+                for i in range(lightcollection.GetNumberOfItems()):
+                    light = lightcollection.GetNextItem()
+                    callback(light, i)
+
+            def cameralight_transform(light, xform, light_type):
+                # transform light by 4x4 matrix xform
+                origin = x3to4( light.GetPosition() )
+                focus = x3to4( light.GetFocalPoint() )
+                neworigin = xform.MultiplyPoint(origin)
+                newfocus = xform.MultiplyPoint(focus)
+                light.SetPosition(x4to3(neworigin))
+                light.SetFocalPoint(x4to3(newfocus))
+                light.SetLightType(light_type)
+            ########################################
+
+            # Save setting of existing lights.
+            light_cfg = []
+            def save_light(light, light_cfg=light_cfg):
+                light_cfg.append(light.GetLightType())
+            for_each_light(self.ren, lambda l, i: save_light(l))
+
+            # Convert lights to scene lights.
+            cam = self.ren.GetActiveCamera()
+            xform = vtk.vtkMatrix4x4()
+            xform.DeepCopy(cam.GetCameraLightTransformMatrix())
+            for_each_light(self.ren, lambda l, i: \
+                           cameralight_transform(l, xform, 3))
+
+            # Write the RIB file.
             ex.SetRenderWindow (self.renwin)
             if bg:
                 ex.BackgroundOn ()
             else:
                 ex.BackgroundOff ()
             ex.Write ()
-            Common.state.idle ()        
+
+            # Now re-convert lights to camera lights.
+            xform.Invert()
+            for_each_light(self.ren, lambda l, i: \
+                           cameralight_transform(l, xform, light_cfg[i]) )
+
+            # Change the camera position. Otherwise VTK would render
+            # one broken frame after the export.
+            cam.Roll(0.5)
+            cam.Roll(-0.5)
+            
+            Common.state.idle ()
 
     def save_wavefront (self, file_name=""):        
         """Save scene to a Wavefront OBJ file.  Two files are
@@ -502,7 +561,7 @@ class RenderWindow (Base.Objects.VizObject):
                                              ("All files", "*")])
         if len (file_name) != 0:
             Common.state.busy ()
-            ex = vtkpython.vtkOBJExporter ()
+            ex = vtk.vtkOBJExporter ()
             self.lift ()
             ex.SetInput (self.renwin)
             f_pref = os.path.splitext (file_name)[0]
@@ -528,7 +587,7 @@ class RenderWindow (Base.Objects.VizObject):
         """
         debug ("In RenderWindow::save_gl2ps ()")
         # Make sure the exporter is available.
-        if not hasattr(vtkpython, 'vtkGL2PSExporter'):
+        if not hasattr(vtk, 'vtkGL2PSExporter'):
             msg = "Saving as a vector PS/EPS/PDF/TeX file using GL2PS is "\
                   "either not supported by your version of VTK or "\
                   "you have not configured VTK to work with GL2PS -- read "\
@@ -552,12 +611,12 @@ class RenderWindow (Base.Objects.VizObject):
             ex = None
             if exp:
                 ex = exp
-                if not isinstance(exp, vtkpython.vtkGL2PSExporter):
+                if not isinstance(exp, vtk.vtkGL2PSExporter):
                     msg = "Need a vtkGL2PSExporter you passed a "\
                           "%s"%exp.__class__.__name__
                 ex.SetFilePrefix(f_prefix)
             else:
-                ex = vtkpython.vtkGL2PSExporter()
+                ex = vtk.vtkGL2PSExporter()
                 # defaults
                 ex.SetFilePrefix(f_prefix)
                 if f_ext == ".ps":
