@@ -9,12 +9,12 @@ Copyright (c) 2001-2002, Prabhu Ramachandran.
 """
 
 __author__ = "Prabhu Ramachandran <prabhu_r@users.sf.net>"
-__version__ = "$Revision: 1.9 $"
-__date__ = "$Date: 2004/07/06 04:29:31 $"
+__version__ = "$Revision: 1.11 $"
+__date__ = "$Date: 2005/08/02 18:30:13 $"
 
 import Common, Base.Objects
 import Tkinter, tkColorChooser
-import vtkpython
+import vtk
 import vtkPipeline.vtkMethodParser
 
 debug = Common.debug
@@ -28,7 +28,7 @@ class Axes (Base.Objects.Module):
         debug ("In Axes::__init__ ()")
         Common.state.busy ()
         Base.Objects.Module.__init__ (self, mod_m)
-        self.axes = vtkpython.vtkCubeAxesActor2D ()
+        self.axes = vtk.vtkCubeAxesActor2D ()
         txt = ("X", "Y", "Z")
         for i in range (0, 3):
             eval ("self.axes.%sAxisVisibilityOn ()"%(txt[i]))
@@ -41,8 +41,13 @@ class Axes (Base.Objects.Module):
         self.axes.GetProperty ().SetColor (*Common.config.fg_color)
         self.axes.SetCamera (self.renwin.get_active_camera ())
         if hasattr(self.axes, "GetAxisTitleTextProperty"):
-            self.axes.GetAxisTitleTextProperty().ShadowOff()
-            self.axes.GetAxisLabelTextProperty().ShadowOff()
+            ttp = self.axes.GetAxisTitleTextProperty()
+            ltp = self.axes.GetAxisLabelTextProperty()
+            ttp.ShadowOff()
+            fg_color = Common.config.fg_color
+            ttp.SetColor(fg_color)
+            ltp.SetColor(fg_color)
+            ltp.ShadowOff()
         else:
             self.axes.ShadowOff ()
         self.renwin.add_actors (self.axes)
@@ -115,11 +120,20 @@ class Axes (Base.Objects.Module):
         for obj in (self.axes, self.axes.GetProperty ()):
             p.load (obj, file)
 
+        if hasattr(self.axes, "GetAxisTitleTextProperty"):
+            clr = self.axes.GetProperty().GetColor()
+            self.axes.GetAxisTitleTextProperty().SetColor(clr)
+            self.axes.GetAxisLabelTextProperty().SetColor(clr)
+
         self._gui_vars_init ()
 
     def config_changed (self): 
         debug ("In Axes::config_changed ()")
-        self.axes.GetProperty ().SetColor (*Common.config.fg_color)
+        fg_color = Common.config.fg_color
+        self.axes.GetProperty ().SetColor (fg_color)
+        if hasattr(self.axes, "GetAxisTitleTextProperty"):
+            self.axes.GetAxisTitleTextProperty().SetColor(fg_color)
+            self.axes.GetAxisLabelTextProperty().SetColor(fg_color)
         
     def make_main_gui (self):
         debug ("In Axes::make_main_gui ()")
@@ -210,12 +224,13 @@ class Axes (Base.Objects.Module):
 
     def set_shadow (self, event=None):
         debug ("In Axes::set_shadow ()")
+        shadow = self.shadow_on_var.get()
         if hasattr(self.axes, "GetAxisTitleTextProperty"):
-            self.axes.GetAxisTitleTextProperty().SetShadow (self.shadow_on_var.get ())
-            self.axes.GetAxisLabelTextProperty().SetShadow (self.shadow_on_var.get ())
+            self.axes.GetAxisTitleTextProperty().SetShadow (shadow)
+            self.axes.GetAxisLabelTextProperty().SetShadow (shadow)
             
         else:
-            self.axes.SetShadow (self.shadow_on_var.get ())
+            self.axes.SetShadow (shadow)
         self.renwin.Render ()
         
     def set_scaling (self, event=None):
@@ -242,4 +257,7 @@ class Axes (Base.Objects.Module):
         if color[1] is not None:
             clr = Common.tk_2_vtk_color (color[0])
             self.axes.GetProperty ().SetColor (*clr)
+            if hasattr(self.axes, "GetAxisTitleTextProperty"):
+                self.axes.GetAxisTitleTextProperty().SetColor(clr)
+                self.axes.GetAxisLabelTextProperty().SetColor(clr)
             self.renwin.Render ()
