@@ -17,12 +17,12 @@ Copyright (c) 2001-2002, Prabhu Ramachandran.
 """
 
 __author__ = "Prabhu Ramachandran <prabhu_r@users.sf.net>"
-__version__ = "$Revision: 1.10 $"
-__date__ = "$Date: 2004/07/06 04:29:31 $"
+__version__ = "$Revision: 1.11 $"
+__date__ = "$Date: 2005/08/02 18:30:13 $"
 
 import Base.Objects, Common
 import Tkinter, tkColorChooser
-import vtkpython
+import vtk
 import vtkPipeline.vtkMethodParser
 
 debug = Common.debug
@@ -51,21 +51,21 @@ class CustomGridPlane (Base.Objects.Module):
         self.act = None
         out = self.mod_m.GetOutput ()
         if out.IsA('vtkStructuredGrid'):
-            self.plane = vtkpython.vtkStructuredGridGeometryFilter ()
+            self.plane = vtk.vtkStructuredGridGeometryFilter ()
         elif out.IsA ('vtkStructuredPoints') or out.IsA('vtkImageData'):
-            if hasattr (vtkpython, 'vtkImageDataGeometryFilter'):
-                self.plane = vtkpython.vtkImageDataGeometryFilter ()
+            if hasattr (vtk, 'vtkImageDataGeometryFilter'):
+                self.plane = vtk.vtkImageDataGeometryFilter ()
             else:
-                self.plane = vtkpython.vtkStructuredPointsGeometryFilter ()
+                self.plane = vtk.vtkStructuredPointsGeometryFilter ()
         elif out.IsA ('vtkRectilinearGrid'):
-            self.plane = vtkpython.vtkRectilinearGridGeometryFilter ()
+            self.plane = vtk.vtkRectilinearGridGeometryFilter ()
         else:
             msg = "This module does not support the %s dataset."%(out.GetClassName())
             raise Base.Objects.ModuleException, msg
 
-        self.cont_fil = vtkpython.vtkContourFilter ()
-        self.mapper = self.map = vtkpython.vtkPolyDataMapper ()
-        self.actor = self.act = vtkpython.vtkActor ()
+        self.cont_fil = vtk.vtkContourFilter ()
+        self.mapper = self.map = vtk.vtkPolyDataMapper ()
+        self.actor = self.act = vtk.vtkActor ()
         self._initialize ()
         self._gui_init ()
         self.renwin.Render ()
