@@ -11,12 +11,12 @@ Copyright (c) 2003, Prabhu Ramachandran.
 """
 
 __author__ = "Prabhu Ramachandran <prabhu_r@users.sf.net>"
-__version__ = "$Revision: 1.4 $"
-__date__ = "$Date: 2004/07/06 04:29:31 $"
+__version__ = "$Revision: 1.5 $"
+__date__ = "$Date: 2005/08/02 18:30:13 $"
 
 import Base.Objects, Common
 import Tkinter, tkColorChooser, math
-import vtkpython
+import vtk
 import vtkPipeline.vtkMethodParser
 import vtkPipeline.ConfigVtkObj
 
@@ -33,10 +33,10 @@ class Glyph (Base.Objects.Module):
         debug ("In Glyph::__init__ ()")
         Common.state.busy ()
         Base.Objects.Module.__init__ (self, mod_m)
-        self.glyph_src = vtkpython.vtkGlyphSource2D ()
-        self.glyph = vtkpython.vtkGlyph3D ()
-        self.mapper = self.map = vtkpython.vtkPolyDataMapper ()
-        self.actor = self.act = vtkpython.vtkActor ()
+        self.glyph_src = vtk.vtkGlyphSource2D ()
+        self.glyph = vtk.vtkGlyph3D ()
+        self.mapper = self.map = vtk.vtkPolyDataMapper ()
+        self.actor = self.act = vtk.vtkActor ()
         self.data_out = self.mod_m.GetOutput ()
         
         self._initialize ()
@@ -191,20 +191,20 @@ class Glyph (Base.Objects.Module):
         Common.state.busy ()
         val = self.glyph_var.get ()
         if val == 0: # 2d glyph 
-            self.glyph_src = vtkpython.vtkGlyphSource2D ()
+            self.glyph_src = vtk.vtkGlyphSource2D ()
             self.glyph_src.SetGlyphTypeToArrow ()
         elif val == 1: # Cone
-            self.glyph_src = vtkpython.vtkConeSource()
+            self.glyph_src = vtk.vtkConeSource()
         elif val == 2: # Sphere
-            self.glyph_src = vtkpython.vtkSphereSource()
+            self.glyph_src = vtk.vtkSphereSource()
             self.glyph_src.SetPhiResolution(4)
             self.glyph_src.SetThetaResolution(4)
         elif val == 3: # Cube
-            self.glyph_src = vtkpython.vtkCubeSource()
+            self.glyph_src = vtk.vtkCubeSource()
         elif val == 4: # Cylinder
-            self.glyph_src = vtkpython.vtkCylinderSource()
+            self.glyph_src = vtk.vtkCylinderSource()
         elif val == 5: # 3D arrow
-            self.glyph_src = vtkpython.vtkArrowSource()
+            self.glyph_src = vtk.vtkArrowSource()
         self.glyph.SetSource (self.glyph_src.GetOutput ())
 
         self.renwin.Render ()
