@@ -11,12 +11,12 @@ Copyright (c) 2001-2002, Prabhu Ramachandran.
 """
 
 __author__ = "Prabhu Ramachandran <prabhu_r@users.sf.net>"
-__version__ = "$Revision: 1.5 $"
-__date__ = "$Date: 2004/07/06 04:29:31 $"
+__version__ = "$Revision: 1.6 $"
+__date__ = "$Date: 2005/08/02 18:30:13 $"
 
 import Base.Objects, Common
 import Tkinter, tkColorChooser
-import vtkpython, math
+import vtk, math
 import vtkPipeline.vtkMethodParser
 
 debug = Common.debug
@@ -32,9 +32,9 @@ class HedgeHog (Base.Objects.Module):
         Common.state.busy ()
         Base.Objects.Module.__init__ (self, mod_m)
         self.root = None
-        self.hhog = vtkpython.vtkHedgeHog ()
-        self.mapper = self.map = vtkpython.vtkPolyDataMapper ()
-        self.actor  = self.act = vtkpython.vtkActor ()
+        self.hhog = vtk.vtkHedgeHog ()
+        self.mapper = self.map = vtk.vtkPolyDataMapper ()
+        self.actor  = self.act = vtk.vtkActor ()
         self._initialize ()
         self.renwin.Render ()
         Common.state.idle ()
