@@ -22,12 +22,12 @@ Copyright (c) 2003, Prabhu Ramachandran.
 """
 
 __author__ = "Prabhu Ramachandran <prabhu_r@users.sf.net>"
-__version__ = "$Revision: 1.4 $"
-__date__ = "$Date: 2004/07/06 04:29:31 $"
+__version__ = "$Revision: 1.5 $"
+__date__ = "$Date: 2005/08/02 18:30:13 $"
 
 import Base.Objects, Common
 import Tkinter, tkColorChooser
-import vtkpython
+import vtk
 import vtkPipeline.vtkMethodParser
 import vtkPipeline.ConfigVtkObj
 import tkSimpleDialog
@@ -131,15 +131,15 @@ class Labels (Base.Objects.Module):
         Common.state.busy ()
         self.n_points = n_points
         self.vis_points = vis_points
-        self.mask = vtkpython.vtkMaskPoints ()
+        self.mask = vtk.vtkMaskPoints ()
         n = input.GetNumberOfPoints ()
         self.mask.SetInput (input)
         self.mask.SetOnRatio (max(n/n_points, 1))
         self.mask.GenerateVerticesOn()
         self.mask.RandomModeOn ()
-        self.vis_pnts = vtkpython.vtkSelectVisiblePoints ()
+        self.vis_pnts = vtk.vtkSelectVisiblePoints ()
         self.vis_pnts.SetRenderer(self.renwin.get_renderer())
-        self.mapper = self.map = vtkpython.vtkLabeledDataMapper ()
+        self.mapper = self.map = vtk.vtkLabeledDataMapper ()
         self.mapper.SetLabelModeToLabelScalars()
         self.tprop = None
         if hasattr(self.mapper, "GetLabelTextProperty"):
@@ -153,7 +153,7 @@ class Labels (Base.Objects.Module):
         else:
             self.mapper.SetInput (self.mask.GetOutput ())
             
-        self.actor = self.act = vtkpython.vtkActor2D ()
+        self.actor = self.act = vtk.vtkActor2D ()
         self.actor.SetMapper (self.mapper)
         self.vis_pnt_gui = None
         self.act.GetProperty ().SetColor (*Common.config.fg_color)
