@@ -9,12 +9,12 @@ Copyright (c) 2001-2002, Prabhu Ramachandran.
 """
 
 __author__ = "Prabhu Ramachandran <prabhu_r@users.sf.net>"
-__version__ = "$Revision: 1.5 $"
-__date__ = "$Date: 2004/07/06 04:29:31 $"
+__version__ = "$Revision: 1.6 $"
+__date__ = "$Date: 2005/08/02 18:30:13 $"
 
 import Base.Objects, Common
 import Tkinter, tkColorChooser
-import vtkpython
+import vtk
 import vtkPipeline.vtkMethodParser
 
 debug = Common.debug
@@ -27,11 +27,11 @@ class Outline (Base.Objects.Module):
         Base.Objects.Module.__init__ (self, mod_m)
         data_src = self.mod_m.get_data_source ()
         self.type = data_src.get_grid_type ()
-        self.outline = vtkpython.vtkOutlineFilter ()
+        self.outline = vtk.vtkOutlineFilter ()
         self.outline.SetInput (mod_m.GetOutput ())
-        self.mapper = self.map = vtkpython.vtkPolyDataMapper ()
+        self.mapper = self.map = vtk.vtkPolyDataMapper ()
         self.map.SetInput (self.outline.GetOutput ())
-        self.actor = self.act = vtkpython.vtkActor ()  
+        self.actor = self.act = vtk.vtkActor ()  
         self.act.SetMapper (self.map)
         self.act.GetProperty ().SetColor (*Common.config.fg_color)
         self.renwin.add_actors (self.act)
