@@ -9,12 +9,12 @@ Copyright (c) 2001-2002, Prabhu Ramachandran.
 """
 
 __author__ = "Prabhu Ramachandran <prabhu_r@users.sf.net>"
-__version__ = "$Revision: 1.6 $"
-__date__ = "$Date: 2004/10/18 12:57:01 $"
+__version__ = "$Revision: 1.7 $"
+__date__ = "$Date: 2005/08/02 18:30:13 $"
 
 import Base.Objects, Common
 import Tkinter, tkColorChooser
-import vtkpython
+import vtk
 import vtkPipeline.vtkMethodParser
 
 debug = Common.debug
@@ -34,12 +34,12 @@ class PolyData (Base.Objects.Module):
             raise Base.Objects.ModuleException, msg
 
         self.root = None
-        self.mapper = self.map = vtkpython.vtkPolyDataMapper ()
+        self.mapper = self.map = vtk.vtkPolyDataMapper ()
         self.map.SetInput (mod_m.GetOutput ())
         self.map.SetLookupTable (self.mod_m.get_scalar_lut ())
         self.data_range = self.mod_m.get_scalar_data_range ()
         self.map.SetScalarRange (self.data_range)
-        self.actor = self.act = vtkpython.vtkActor ()  
+        self.actor = self.act = vtk.vtkActor ()  
         self.act.SetMapper (self.map)
         self.act.GetProperty ().SetColor (0.0, 0.1, 0.8)
         # used for the pipeline browser
