@@ -12,12 +12,12 @@ Copyright (c) 2001-2002, Prabhu Ramachandran.
 """
 
 __author__ = "Prabhu Ramachandran <prabhu_r@users.sf.net>"
-__version__ = "$Revision: 1.7 $"
-__date__ = "$Date: 2003/10/11 18:59:55 $"
+__version__ = "$Revision: 1.8 $"
+__date__ = "$Date: 2005/08/02 18:30:13 $"
 
 import Base.Objects, Common
 import Tkinter, tkColorChooser, tkMessageBox, tkFileDialog, math
-import vtkpython
+import vtk
 import vtkPipeline.vtkMethodParser
 import vtkPipeline.ConfigVtkObj
 
@@ -51,13 +51,13 @@ class SeedManager:
         assert len (valid_coord) == 3
         self.dim = reduce (lambda x, y: x+y, valid_coord)
         if self.dim == 3:
-            self.seed = vtkpython.vtkPointSource ()
+            self.seed = vtk.vtkPointSource ()
         else:
-            self.seed = vtkpython.vtkDiskSource ()
+            self.seed = vtk.vtkDiskSource ()
             self.seed.SetRadialResolution (1)
             self.seed.SetInnerRadius (0.0)
-            self.transform = vtkpython.vtkTransformFilter ()
-            self.transform.SetTransform (vtkpython.vtkTransform ())
+            self.transform = vtk.vtkTransformFilter ()
+            self.transform.SetTransform (vtk.vtkTransform ())
             self.transform.SetInput (self.seed.GetOutput ())
             self.orient_2d (valid_coord)
                 
@@ -123,9 +123,9 @@ class PointStreamer (Base.Objects.Module):
         debug ("In PointStreamer::__init__ ()")
         Common.state.busy ()
         Base.Objects.Module.__init__ (self, mod_m)
-        self.sphere_src = vtkpython.vtkSphereSource ()
-        self.sphere_map = vtkpython.vtkPolyDataMapper ()
-        self.sphere_act = vtkpython.vtkActor ()        
+        self.sphere_src = vtk.vtkSphereSource ()
+        self.sphere_map = vtk.vtkPolyDataMapper ()
+        self.sphere_act = vtk.vtkActor ()        
         self.seed = SeedManager ()
         self.radius = 1.0
         self.cen = [0.0, 0.0, 0.0]
@@ -134,11 +134,11 @@ class PointStreamer (Base.Objects.Module):
         self.color_mode = 1 # 1 is vector, 0 is scalar, -1 is no color
         self.integration_mode = 2 # 2 is Runge-Kutta 2 and 4 is RK 4.
 
-        self.strmln = vtkpython.vtkStreamLine ()
-        self.ribbonf = vtkpython.vtkRibbonFilter ()
-        self.tubef = vtkpython.vtkTubeFilter ()
-        self.mapper = self.stream_map = vtkpython.vtkPolyDataMapper ()
-        self.actor = self.stream_act = vtkpython.vtkActor ()
+        self.strmln = vtk.vtkStreamLine ()
+        self.ribbonf = vtk.vtkRibbonFilter ()
+        self.tubef = vtk.vtkTubeFilter ()
+        self.mapper = self.stream_map = vtk.vtkPolyDataMapper ()
+        self.actor = self.stream_act = vtk.vtkActor ()
         self.done_init = 0
         Common.state.idle ()
 
@@ -515,9 +515,9 @@ class PointStreamer (Base.Objects.Module):
         val = self.integration_mode
         try:
             if val == 2:
-                self.strmln.SetIntegrator (vtkpython.vtkRungeKutta2 ())
+                self.strmln.SetIntegrator (vtk.vtkRungeKutta2 ())
             elif val == 4:
-                self.strmln.SetIntegrator (vtkpython.vtkRungeKutta4 ())
+                self.strmln.SetIntegrator (vtk.vtkRungeKutta4 ())
         except AttributeError, err:            
             msg = "Sorry unable to change the integration type. "\
                   "Try upgrading your VTK installation to a more "\
@@ -545,7 +545,7 @@ class PointStreamer (Base.Objects.Module):
         file.write ("%d, %d, %d\n"%(self.n_pnt, self.strmln_mode,
                                     self.integration_mode))
         # For backward compatibility - the dummy is actually unused.
-        dummy_seed = vtkpython.vtkPointSource ()
+        dummy_seed = vtk.vtkPointSource ()
         p = vtkPipeline.vtkMethodParser.VtkPickler ()
         for i in (self.sphere_src, self.sphere_map, self.sphere_act, 
                   self.sphere_act.GetProperty (),
@@ -563,7 +563,7 @@ class PointStreamer (Base.Objects.Module):
         except ValueError: # old format
             self.n_pnt, self.strmln_mode = eval (val)
         # For backward compatibility - the dummy is actually unused.
-        dummy_seed = vtkpython.vtkPointSource ()        
+        dummy_seed = vtk.vtkPointSource ()        
         p = vtkPipeline.vtkMethodParser.VtkPickler ()
         for i in (self.sphere_src, self.sphere_map, self.sphere_act,
                   self.sphere_act.GetProperty (),
