@@ -10,15 +10,15 @@ Copyright (c) 2001-2002, Prabhu Ramachandran.
 """
 
 __author__ = "Prabhu Ramachandran <prabhu_r@users.sf.net>"
-__version__ = "$Revision: 1.4 $"
-__date__ = "$Date: 2004/07/06 04:29:31 $"
+__version__ = "$Revision: 1.5 $"
+__date__ = "$Date: 2005/08/02 18:30:13 $"
 __credits__ = """Many thanks to Jose Paulo <moitinho@civil.ist.utl.pt>
 for contributing an initial version of this Module."""
 
 
 import Base.Objects, Common
 import Tkinter, tkColorChooser, math
-import vtkpython
+import vtk
 import vtkPipeline.vtkMethodParser
 
 debug = Common.debug
@@ -33,13 +33,13 @@ class TensorGlyphs (Base.Objects.Module):
         Common.state.busy ()
         Base.Objects.Module.__init__ (self, mod_m)
         
-        self.sphere = vtkpython.vtkSphereSource ()
-        self.axes = vtkpython.vtkAxes ()
-        self.glyphs = vtkpython.vtkTensorGlyph ()
+        self.sphere = vtk.vtkSphereSource ()
+        self.axes = vtk.vtkAxes ()
+        self.glyphs = vtk.vtkTensorGlyph ()
         # The actual glyph used is controlled using self.glyph_var
         
-        self.mapper = vtkpython.vtkPolyDataMapper ()
-        self.actor = vtkpython.vtkActor ()
+        self.mapper = vtk.vtkPolyDataMapper ()
+        self.actor = vtk.vtkActor ()
 
         self.data_out = self.mod_m.GetOutput ()
         self.color_mode = 1 # 1 is scalar, -1 none
@@ -68,7 +68,7 @@ class TensorGlyphs (Base.Objects.Module):
         self.glyphs.ClampScalingOn ()
         self.glyphs.SetMaxScaleFactor (5.0)
 
-        self.normals = vtkpython.vtkPolyDataNormals ()
+        self.normals = vtk.vtkPolyDataNormals ()
         self.normals.SetInput (self.glyphs.GetOutput ())
         
         self.mapper.SetInput (self.normals.GetOutput ())
