@@ -11,12 +11,12 @@ Copyright (c) 2001-2002, Prabhu Ramachandran.
 """
 
 __author__ = "Prabhu Ramachandran <prabhu_r@users.sf.net>"
-__version__ = "$Revision: 1.9 $"
-__date__ = "$Date: 2004/07/06 04:29:31 $"
+__version__ = "$Revision: 1.10 $"
+__date__ = "$Date: 2005/08/02 18:30:13 $"
 
 import Base.Objects, Common
 import Tkinter, tkColorChooser, math
-import vtkpython
+import vtk
 import vtkPipeline.vtkMethodParser
 import vtkPipeline.ConfigVtkObj
 
@@ -32,17 +32,17 @@ class VectorCutPlane (Base.Objects.CutPlaneModule):
         debug ("In VectorCutPlane::__init__ ()")
         Common.state.busy ()
         Base.Objects.CutPlaneModule.__init__ (self, mod_m)
-        self.cut = vtkpython.vtkCutter ()
-        self.glyph2d_src = vtkpython.vtkGlyphSource2D ()
-        self.cone = vtkpython.vtkConeSource ()
-        self.arrow = vtkpython.vtkArrowSource ()
+        self.cut = vtk.vtkCutter ()
+        self.glyph2d_src = vtk.vtkGlyphSource2D ()
+        self.cone = vtk.vtkConeSource ()
+        self.arrow = vtk.vtkArrowSource ()
         self.glyph_src = self.cone
-        self.glyph3d = vtkpython.vtkGlyph3D ()
-        self.mapper = self.map = vtkpython.vtkPolyDataMapper ()
-        self.actor = self.act = vtkpython.vtkActor ()
+        self.glyph3d = vtk.vtkGlyph3D ()
+        self.mapper = self.map = vtk.vtkPolyDataMapper ()
+        self.actor = self.act = vtk.vtkActor ()
         # used to orient the cone properly
-        self.glph_trfm = vtkpython.vtkTransformFilter ()
-        self.glph_trfm.SetTransform (vtkpython.vtkTransform ())
+        self.glph_trfm = vtk.vtkTransformFilter ()
+        self.glph_trfm.SetTransform (vtk.vtkTransform ())
         self.data_out = self.mod_m.GetOutput ()
 
         # Point of glyph that is attached -- -1 is tail, 0 is center,
