@@ -10,12 +10,12 @@ Copyright (c) 2001-2002, Prabhu Ramachandran.
 """
 
 __author__ = "Prabhu Ramachandran <prabhu_r@users.sf.net>"
-__version__ = "$Revision: 1.4 $"
-__date__ = "$Date: 2004/07/06 04:29:31 $"
+__version__ = "$Revision: 1.5 $"
+__date__ = "$Date: 2005/08/02 18:30:14 $"
 
 import Base.Objects, Common
 import Tkinter, tkColorChooser, math
-import vtkpython
+import vtk
 import vtkPipeline.vtkMethodParser
 
 debug = Common.debug
@@ -30,12 +30,12 @@ class WarpVectorCutPlane (Base.Objects.CutPlaneModule):
         debug ("In WarpVectorCutPlane::__init__ ()")
         Common.state.busy ()
         Base.Objects.CutPlaneModule.__init__ (self, mod_m)
-        self.cut = vtkpython.vtkCutter ()
-        self.warp = vtkpython.vtkWarpVector ()
-        self.norm = vtkpython.vtkPolyDataNormals ()
-        self.mapper = self.map = vtkpython.vtkPolyDataMapper ()
+        self.cut = vtk.vtkCutter ()
+        self.warp = vtk.vtkWarpVector ()
+        self.norm = vtk.vtkPolyDataNormals ()
+        self.mapper = self.map = vtk.vtkPolyDataMapper ()
         self.map.SetLookupTable (self.mod_m.get_scalar_lut ())
-        self.actor = self.act = vtkpython.vtkActor ()
+        self.actor = self.act = vtk.vtkActor ()
         self.data_out = self.mod_m.GetOutput ()
         self._initialize ()
         self._gui_init ()
