@@ -15,13 +15,13 @@ Copyright (c) 2001-2003, Prabhu Ramachandran.
 """
 
 __author__ = "Prabhu Ramachandran <prabhu_r@users.sf.net>"
-__version__ = "$Revision: 1.7 $"
-__date__ = "$Date: 2004/07/06 04:29:31 $"
+__version__ = "$Revision: 1.10 $"
+__date__ = "$Date: 2005/08/02 18:30:14 $"
 
 import string
 import Tkinter
 import Base.Objects, Common
-import vtkpython, string
+import vtk, string
 import vtkPipeline.vtkMethodParser
 import vtkPipeline.ConfigVtkObj
 from VtkXMLDataReader import get_array_type
@@ -86,6 +86,15 @@ class VtkData (Base.Objects.DataSource):
                            'vtkRectilinearGrid': 'RECTILINEAR_GRID',
                            'vtkPolyData': 'POLYDATA',
                            'vtkUnstructuredGrid': 'UNSTRUCTURED_GRID'}
+        self.writers = {}
+        self.readers = {}
+        for x in self.data_types:
+            if x == 'vtkImageData':
+                self.writers[x] = vtk.vtkStructuredPointsWriter
+                self.readers[x] = vtk.vtkStructuredPointsReader
+            else:
+                self.writers[x] = getattr(vtk, x + 'Writer')
+                self.readers[x] = getattr(vtk, x + 'Reader')
         self.current_type = ''
 
     def _get_type (self, obj):
@@ -145,41 +154,41 @@ class VtkData (Base.Objects.DataSource):
         out = self.data
         pd = out.GetPointData()
         cd = out.GetCellData()
-        name = ""
-        if pd:
-            s = pd.GetScalars()
-            if s:
-                name = s.GetName()
-        elif cd:
-            s = cd.GetScalars()
-            if s:
-                name = s.GetName()                
-        self.scalar_var.set (name)
-        self.scalar_data_name = name
+        if not self.scalar_data_name:
+            if pd:
+                s = pd.GetScalars()
+                if s:
+                    self.scalar_data_name = s.GetName()
+        if not self.scalar_data_name:
+            if cd:
+                s = cd.GetScalars()
+                if s:
+                    self.scalar_data_name = s.GetName()
+        self.scalar_var.set(self.scalar_data_name)
 
-        name = ""
-        if pd:
-            v = pd.GetVectors()
-            if v:
-                name = v.GetName()
-        elif cd:
-            v = cd.GetVectors()
-            if v:
-                name = v.GetName()
-        self.vector_var.set (name)
-        self.vector_data_name = name        
+        if not self.vector_data_name:
+            if pd:
+                v = pd.GetVectors()
+                if v:
+                    self.vector_data_name = v.GetName()
+        if not self.vector_data_name:
+            if cd:
+                v = cd.GetVectors()
+                if v:
+                    self.vector_data_name = v.GetName()
+        self.vector_var.set(self.vector_data_name)
 
-        name = ""
-        if pd:
-            t = pd.GetTensors()
-            if t:
-                name = t.GetName()
-        elif cd:
-            t = cd.GetTensors()
-            if t:
-                name = t.GetName()
-        self.tensor_var.set (name)
-        self.tensor_data_name = name
+        if not self.tensor_data_name:
+            if pd:
+                t = pd.GetTensors()
+                if t:
+                    self.tensor_data_name = t.GetName()
+        if not self.tensor_data_name:
+            if cd:
+                t = cd.GetTensors()
+                if t:
+                    self.tensor_data_name = t.GetName()
+        self.tensor_var.set(self.tensor_data_name)
 
     def set_scalar_name (self, scalar): 
         debug ("In VtkData::set_scalar_name ()")
@@ -275,8 +284,7 @@ class VtkData (Base.Objects.DataSource):
         debug ("In VtkData::save_config ()")
         # write the data to a vtk file.
         filename = file.name + '.vtk'
-        writer_name = self.current_type + 'Writer'
-        writer = getattr (vtkpython, writer_name) ()
+        writer = self.writers[self.current_type]()
         writer.SetFileName (filename)
         writer.SetInput (self.data)
         writer.Write ()        
@@ -303,11 +311,14 @@ class VtkData (Base.Objects.DataSource):
         self.current_type = typ
         self.grid_type = self.data_types[typ]
         # read data from vtk file.
-        reader_name = self.current_type + 'Reader'
-        reader = getattr (vtkpython, reader_name) ()
+        reader = self.readers[self.current_type]()
         reader.SetFileName (filename)
-        reader.Update ()        
-        self.data = reader.GetOutput ()
+        reader.Update ()
+        if self.current_type == 'vtkImageData':
+            self.data = vtk.vtkImageData()
+            self.data.DeepCopy(reader.GetOutput())
+        else:
+            self.data = reader.GetOutput ()
         # now read the config for the object
         p = vtkPipeline.vtkMethodParser.VtkPickler ()
         p.load (self.data, file)
