@@ -20,7 +20,7 @@ All of this makes using VTK from Python much easier and much more fun.
 Example session:
 
   >>> import ivtk
-  >>> from vtkpython import *
+  >>> from vtk import *
   >>> c = vtkConeSource()
   >>> m = vtkPolyDataMapper()
   >>> m.SetInput(c.GetOutput())
@@ -41,7 +41,7 @@ Example session:
   >>> import ivtk
   >>> d = ivtk.doc_browser()
   # pops up a standalone searcheable VTK class help browser.
-  >>> from vtkpython import *
+  >>> from vtk import *
   >>> c = vtkConeSource()
   >>> ivtk.doc(c)            # pops up class documentation for c
   >>> ivtk.doc('vtkObject')  # class documentation for vtkObject.
@@ -59,12 +59,12 @@ Copyright (c) 2001-2002, Prabhu Ramachandran.
 """
 
 __author__ = "Prabhu Ramachandran <prabhu_r@users.sf.net>"
-__version__ = "$Revision: 1.12 $"
-__date__ = "$Date: 2004/07/06 04:29:15 $"
+__version__ = "$Revision: 1.13 $"
+__date__ = "$Date: 2005/08/02 18:26:22 $"
 
 
 import types, string, re
-import vtkpython
+import vtk
 import Tkinter, tkColorChooser
 from vtkPipeline.ConfigVtkObj import ConfigVtkObj, VtkShowDoc, print_err
 import vtkPipeline.vtkPipeline
@@ -92,7 +92,7 @@ def doc (obj):
         object that you want documentation for.
     """
     if type (obj) is types.StringType:
-        o = eval ('vtkpython.%s()'%obj)
+        o = eval ('vtk.%s()'%obj)
     else:
         o = obj
 
@@ -335,7 +335,7 @@ class VtkHelp:
             self.root = Tkinter.Tk ()
             self.root.withdraw ()
 
-        self.vtk_classes = dir (vtkpython)
+        self.vtk_classes = dir (vtk)
 
         n = len (self.vtk_classes)
         self.vtk_c_name = ['']*n
@@ -347,7 +347,7 @@ class VtkHelp:
             self.vtk_c_name[i] = string.lower (c)
             if c[:3] == 'vtk':
                 try:
-                    doc = string.lower (getattr(vtkpython, c).__doc__)
+                    doc = string.lower (getattr(vtk, c).__doc__)
                     self.vtk_c_doc[i] = doc
                 except AttributeError:
                     pass
@@ -363,9 +363,9 @@ class VtkHelp:
 
         if type (obj) is types.StringType:
             try:
-                o = eval ('vtkpython.%s()'%obj)
+                o = eval ('vtk.%s()'%obj)
             except AttributeError:
-                print "Sorry vtkpython does not have the class %s"%obj
+                print "Sorry vtk does not have the class %s"%obj
                 return
         else:
             o = obj
