@@ -20,7 +20,7 @@ License:
 """
 
 import mayavi
-import vtkpython
+import vtk
 import Numeric
 
 try:
@@ -59,7 +59,7 @@ def array2vtk(z):
                'D':vtkConstants.VTK_DOUBLE }
 
     # A dummy array used to create others.
-    f = vtkpython.vtkFloatArray()
+    f = vtk.vtkFloatArray()
     # First create an array of the right type by using the typecode.
     tmp = f.CreateDataArray(arr_vtk[z.typecode()])
     tmp.SetReferenceCount(2) # Prevents memory leak.
@@ -116,7 +116,7 @@ def _create_structured_points_pyvtk(x, y, z):
     d.tofile(file_name, format='ascii')
 
     # read the created file - yes this is circuitous but works for now.
-    reader = vtkpython.vtkStructuredPointsReader()
+    reader = vtk.vtkStructuredPointsReader()
     reader.SetFileName(file_name)
     reader.Update()
     # cleanup.
@@ -150,7 +150,7 @@ def _create_structured_points_direct(x, y, z=None):
     xmin, ymin = x[0], y[0]
     dx, dy= (x[1] - x[0]), (y[1] - y[0])
 
-    sp = vtkpython.vtkStructuredPoints()
+    sp = vtk.vtkStructuredPoints()
     sp.SetDimensions(nx, ny, 1)
     sp.SetOrigin(xmin, ymin, 0)
     sp.SetSpacing(dx, dy, 1)
@@ -422,7 +422,7 @@ def viewi(arr, smooth=0, lut='br', scale=[1.0, 1.0, 1.0]):
     luth.range_on_var.set(1)
     luth.set_range_on()
     
-    ia = vtkpython.vtkImageActor()
+    ia = vtk.vtkImageActor()
     if smooth:
         ia.InterpolateOn()
     else:
