@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #
-# $Id: ConfigVtkObj.py,v 1.28 2004/07/06 04:29:31 prabhu_r Exp $
+# $Id: ConfigVtkObj.py,v 1.30 2005/08/02 18:30:14 prabhu_r Exp $
 #
 # This python program/module takes a VTK object and provides a GUI 
 # configuration for it.
@@ -566,9 +566,9 @@ class ConfigVtkObjFrame(Tkinter.Frame):
 
     def destroy(self):
         Tkinter.Frame.destroy(self)
-        del self.vtk_obj
-        del self.renwin
-        del self.update_meth
+        self.vtk_obj = None
+        self.renwin = None
+        self.update_meth = None
 
 
 class ConfigVtkObj:
@@ -762,16 +762,16 @@ class ConfigVtkObj:
         "Ok button clicked."
         self.config_frame.apply_changes ()
         self.root.destroy ()
-        del self.renwin
-        del self.vtk_obj
-        del self.config_frame
+        self.renwin = None
+        self.vtk_obj = None
+        self.config_frame = None
 
     def cancel (self, event=None):
         "Cancel button clicked."
         self.root.destroy ()
-        del self.renwin
-        del self.vtk_obj
-        del self.config_frame
+        self.renwin = None
+        self.vtk_obj = None
+        self.config_frame = None
 
     def show (self):
         "Print the various methods of the vtkobject."
@@ -782,24 +782,24 @@ class ConfigVtkObj:
 
 
 if __name__ == "__main__":  
-    import vtkpython
-    import vtkRenderWidget
-    cone = vtkpython.vtkConeSource()
+    import vtk
+    from vtk.tk import vtkTkRenderWidget
+    cone = vtk.vtkConeSource()
     cone.SetResolution(8)
-    coneMapper = vtkpython.vtkPolyDataMapper()
+    coneMapper = vtk.vtkPolyDataMapper()
     coneMapper.SetInput(cone.GetOutput())
-    coneActor = vtkpython.vtkActor()
+    coneActor = vtk.vtkActor()
     coneActor.SetMapper(coneMapper)
-    axes = vtkpython.vtkCubeAxesActor2D ()
+    axes = vtk.vtkCubeAxesActor2D ()
 
     def quit (event=None):
         root.destroy ()
 
     root = Tkinter.Tk ()
-    wid = vtkRenderWidget.vtkTkRenderWidget (root, width=500, height=500)
+    wid = vtkTkRenderWidget.vtkTkRenderWidget (root, width=500, height=500)
     wid.pack (expand=1, fill='both')
     wid.bind ("<KeyPress-q>", quit)
-    ren = vtkpython.vtkRenderer()
+    ren = vtk.vtkRenderer()
     renWin = wid.GetRenderWindow()
     renWin.AddRenderer(ren)
     renWin.SetSize(500,500)
