@@ -1,4 +1,4 @@
-# $Id: vtkMethodParser.py,v 1.16 2004/07/06 04:29:31 prabhu_r Exp $
+# $Id: vtkMethodParser.py,v 1.17 2005/07/27 18:37:36 prabhu_r Exp $
 #
 # This python program/module provides functionality to parse the
 # methods of a VTK object and the ability to save and reload the
@@ -27,6 +27,15 @@ of a VTK object.
 import string, re, sys
 import types
 
+try:
+    # Shut up deprecation warnings for changes of function signatures
+    # to int from float.
+    import warnings
+    warnings.filterwarnings('ignore', category=DeprecationWarning)
+except ImportError:
+    pass
+
+
 # set this to 1 if you want to see debugging messages - very useful if
 # you have problems
 DEBUG=0
@@ -202,6 +211,13 @@ class VtkDirMethodParser:
                 self.get_meths.append (method)
                 self.methods.remove (method)
 
+        # These aren't state methods.
+        ignore = ['SetUpdateExtentToWholeExtent', 'SetInputArrayToProcess']
+        for method in self.state_meths[:]:
+            if method in ignore:
+                self.methods.append(method)
+                self.state_meths.remove(method)
+
         # Grouping similar state methods
         if len (self.state_meths) != 0:
             tmp = self.state_meths[:]
